@@ -3,24 +3,32 @@ use strict;
 use warnings;
 use Test::More qw//;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Exporter;
 our @ISA    = qw/Exporter/;
-our @EXPORT = qw/check_no_load/;
+our @EXPORT = qw/check_no_load load_ok/;
 
 sub check_no_load {
     my @modules = @_;
 
     for my $module (@modules) {
-        Test::More::ok( _check_no_load($module), "no load: $module" );
+        Test::More::ok( !_loaded($module), "no load: $module" );
     }
 }
 
-sub _check_no_load {
+sub _loaded {
     my $module = shift;
     $module =~ s!::!/!g;
-    return !defined( $INC{"$module\.pm"} );
+    return defined( $INC{"$module\.pm"} );
+}
+
+sub load_ok {
+    my @modules = @_;
+
+    for my $module (@modules) {
+        Test::More::ok( _loaded($module), "loaded: $module" );
+    }
 }
 
 1;
